diff --git a/make/jdk/src/classes/build/tools/generatelsrequivmaps/EquivMapsGenerator.java b/make/jdk/src/classes/build/tools/generatelsrequivmaps/EquivMapsGenerator.java index a4e673d0dae..7d1b7b261d5 100644 --- a/make/jdk/src/classes/build/tools/generatelsrequivmaps/EquivMapsGenerator.java +++ b/make/jdk/src/classes/build/tools/generatelsrequivmaps/EquivMapsGenerator.java @@ -132,7 +132,7 @@ public class EquivMapsGenerator { + " A region/variant subtag \"" + preferred + "\" is registered for more than one subtags."); } - } else { // language, extlang, grandfathered, and redundant + } else { // language, extlang, legacy, and redundant if (!initialLanguageMap.containsKey(preferred)) { sb = new StringBuilder(preferred); sb.append(','); diff --git a/src/java.base/share/classes/java/io/ObjectInputFilter.java b/src/java.base/share/classes/java/io/ObjectInputFilter.java index 9df7c6ed280..3f221b1c89f 100644 --- a/src/java.base/share/classes/java/io/ObjectInputFilter.java +++ b/src/java.base/share/classes/java/io/ObjectInputFilter.java @@ -1,5 +1,5 @@ /* - * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved. + * Copyright (c) 2016, 2020, Oracle and/or its affiliates. All rights reserved. * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER. * * This code is free software; you can redistribute it and/or modify it @@ -64,7 +64,7 @@ import jdk.internal.util.StaticProperty; * {@link Status#UNDECIDED UNDECIDED}. * Filters should be designed for the specific use case and expected types. * A filter designed for a particular use may be passed a class that is outside - * of the scope of the filter. If the purpose of the filter is to black-list classes + * of the scope of the filter. If the purpose of the filter is to reject classes * then it can reject a candidate class that matches and report UNDECIDED for others. * A filter may be called with class equals {@code null}, {@code arrayLength} equal -1, * the depth, number of references, and stream size and return a status diff --git a/src/java.base/share/classes/java/util/Locale.java b/src/java.base/share/classes/java/util/Locale.java index a01e279b46a..c4f23494bd0 100644 --- a/src/java.base/share/classes/java/util/Locale.java +++ b/src/java.base/share/classes/java/util/Locale.java @@ -1645,18 +1645,19 @@ public final class Locale implements Cloneable, Serializable { * * *
This implements the 'Language-Tag' production of BCP47, and - * so supports grandfathered (regular and irregular) as well as + * so supports legacy (regular and irregular, referred to as + * "Type: grandfathered" in BCP47) as well as * private use language tags. Stand alone private use tags are * represented as empty language and extension 'x-whatever', - * and grandfathered tags are converted to their canonical replacements + * and legacy tags are converted to their canonical replacements * where they exist. * - *
Grandfathered tags with canonical replacements are as follows: + *
Legacy tags with canonical replacements are as follows: * *
grandfathered tag | modern replacement |
---|---|
legacy tag | modern replacement |
art-lojban | jbo |
Grandfathered tags with no modern replacement will be + *
Legacy tags with no modern replacement will be * converted as follows: * *
grandfathered tag | converts to |
---|---|
legacy tag | converts to |
cel-gaulish | xtg-x-cel-gaulish |
For a list of all grandfathered tags, see the + *
For a list of all legacy tags, see the * IANA Language Subtag Registry (search for "Type: grandfathered"). * *
Note: there is no guarantee that {@code toLanguageTag} @@ -2586,7 +2587,7 @@ public final class Locale implements Cloneable, Serializable { * Resets the Builder to match the provided IETF BCP 47 * language tag. Discards the existing state. Null and the * empty string cause the builder to be reset, like {@link - * #clear}. Grandfathered tags (see {@link + * #clear}. Legacy tags (see {@link * Locale#forLanguageTag}) are converted to their canonical * form before being processed. Otherwise, the language tag * must be well-formed (see {@link Locale}) or an exception is @@ -2838,7 +2839,7 @@ public final class Locale implements Cloneable, Serializable { * on this builder. * *
This applies the conversions listed in {@link Locale#forLanguageTag}
- * when constructing a Locale. (Grandfathered tags are handled in
+ * when constructing a Locale. (Legacy tags are handled in
* {@link #setLanguageTag}.)
*
* @return A Locale.
diff --git a/src/java.base/share/classes/jdk/internal/logger/BootstrapLogger.java b/src/java.base/share/classes/jdk/internal/logger/BootstrapLogger.java
index 6012e11b780..dd37f5174b8 100644
--- a/src/java.base/share/classes/jdk/internal/logger/BootstrapLogger.java
+++ b/src/java.base/share/classes/jdk/internal/logger/BootstrapLogger.java
@@ -847,7 +847,7 @@ public final class BootstrapLogger implements Logger, PlatformLogger.Bridge,
else return VM.isBooted();
}
- // A bit of black magic. We try to find out the nature of the logging
+ // A bit of magic. We try to find out the nature of the logging
// backend without actually loading it.
private static enum LoggingBackend {
// There is no LoggerFinder and JUL is not present
diff --git a/src/java.base/share/classes/sun/util/locale/LanguageTag.java b/src/java.base/share/classes/sun/util/locale/LanguageTag.java
index a2d745794ab..1ba11d9dca6 100644
--- a/src/java.base/share/classes/sun/util/locale/LanguageTag.java
+++ b/src/java.base/share/classes/sun/util/locale/LanguageTag.java
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2020, Oracle and/or its affiliates. All rights reserved.
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
*
* This code is free software; you can redistribute it and/or modify it
@@ -60,10 +60,10 @@ public class LanguageTag {
private List
@@ -149,7 +149,7 @@ public class RMIConnectorServer extends JMXConnectorServer {
* classes they use in their serial form.
*
* Care must be taken when defining such a filter, as defining
- * a white list too restrictive or a too wide a black list may
+ * an allow-list that is too narrow or a reject-list that is too wide may
* prevent legitimate clients from interoperating with the
* {@code JMXConnectorServer}.
*/
diff --git a/src/java.rmi/share/classes/sun/rmi/registry/RegistryImpl.java b/src/java.rmi/share/classes/sun/rmi/registry/RegistryImpl.java
index 5dacaf3d8f6..223986f4c27 100644
--- a/src/java.rmi/share/classes/sun/rmi/registry/RegistryImpl.java
+++ b/src/java.rmi/share/classes/sun/rmi/registry/RegistryImpl.java
@@ -441,7 +441,7 @@ public class RegistryImpl extends java.rmi.server.RemoteServer
if (registryFilter != null) {
ObjectInputFilter.Status status = registryFilter.checkInput(filterInfo);
if (status != ObjectInputFilter.Status.UNDECIDED) {
- // The Registry filter can override the built-in white-list
+ // The Registry filter can override the built-in allow-list
return status;
}
}
diff --git a/src/java.rmi/share/classes/sun/rmi/transport/DGCImpl.java b/src/java.rmi/share/classes/sun/rmi/transport/DGCImpl.java
index b1c9e6e8476..f2c1115b879 100644
--- a/src/java.rmi/share/classes/sun/rmi/transport/DGCImpl.java
+++ b/src/java.rmi/share/classes/sun/rmi/transport/DGCImpl.java
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 1996, 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2020, Oracle and/or its affiliates. All rights reserved.
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
*
* This code is free software; you can redistribute it and/or modify it
@@ -382,7 +382,7 @@ final class DGCImpl implements DGC {
if (dgcFilter != null) {
ObjectInputFilter.Status status = dgcFilter.checkInput(filterInfo);
if (status != ObjectInputFilter.Status.UNDECIDED) {
- // The DGC filter can override the built-in white-list
+ // The DGC filter can override the built-in allow-list
return status;
}
}
diff --git a/test/jdk/java/lang/ClassLoader/Assert.java b/test/jdk/java/lang/ClassLoader/Assert.java
index fb2376d45d4..d894fef5ef9 100644
--- a/test/jdk/java/lang/ClassLoader/Assert.java
+++ b/test/jdk/java/lang/ClassLoader/Assert.java
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2000, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2000, 2020, Oracle and/or its affiliates. All rights reserved.
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
*
* This code is free software; you can redistribute it and/or modify it
@@ -62,7 +62,7 @@ public class Assert {
int[] switches = new int[7];
int switchSource = 0;
- if (args.length == 0) { // This is master version
+ if (args.length == 0) { // This is the controller
// This code is for an exhaustive test
//while(switchSource < 2187) {
@@ -92,7 +92,7 @@ public class Assert {
new InputStreamReader(p.getInputStream()));
String outString = blah.readLine();
while (outString != null) {
- System.out.println("from slave:"+outString);
+ System.out.println("from BufferedReader:"+outString);
outString = blah.readLine();
}
}
diff --git a/test/jdk/java/lang/management/ClassLoadingMXBean/LoadCounts.java b/test/jdk/java/lang/management/ClassLoadingMXBean/LoadCounts.java
index 203e263496a..58ef8e36a8d 100644
--- a/test/jdk/java/lang/management/ClassLoadingMXBean/LoadCounts.java
+++ b/test/jdk/java/lang/management/ClassLoadingMXBean/LoadCounts.java
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2020, Oracle and/or its affiliates. All rights reserved.
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
*
* This code is free software; you can redistribute it and/or modify it
@@ -119,9 +119,9 @@ class SimpleOne {}
class SimpleTwo {}
class Chain {
- Slave slave = new Slave();
+ Worker worker = new Worker();
}
-class Slave {}
+class Worker {}
class LeftHand extends ClassLoader {
public LeftHand() {
diff --git a/test/jdk/java/nio/channels/AsynchronousFileChannel/Lock.java b/test/jdk/java/nio/channels/AsynchronousFileChannel/Lock.java
index 13a094e7d25..93df642c275 100644
--- a/test/jdk/java/nio/channels/AsynchronousFileChannel/Lock.java
+++ b/test/jdk/java/nio/channels/AsynchronousFileChannel/Lock.java
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2020, Oracle and/or its affiliates. All rights reserved.
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
*
* This code is free software; you can redistribute it and/or modify it
@@ -45,13 +45,13 @@ public class Lock {
static final Random rand = new Random();
public static void main(String[] args) throws Exception {
- if (args.length > 0 && args[0].equals("-lockslave")) {
+ if (args.length > 0 && args[0].equals("-lockworker")) {
int port = Integer.parseInt(args[1]);
- runLockSlave(port);
+ runLockWorker(port);
System.exit(0);
}
- LockSlaveMirror slave = startLockSlave();
+ LockWorkerMirror worker = startLockWorker();
try {
// create temporary file
@@ -59,31 +59,31 @@ public class Lock {
blah.deleteOnExit();
// run tests
- testLockProtocol(blah, slave);
- testAsyncClose(blah, slave);
+ testLockProtocol(blah, worker);
+ testAsyncClose(blah, worker);
// eagerly clean-up
blah.delete();
} finally {
- slave.shutdown();
+ worker.shutdown();
}
}
// test locking protocol
- static void testLockProtocol(File file, LockSlaveMirror slave)
+ static void testLockProtocol(File file, LockWorkerMirror worker)
throws Exception
{
FileLock fl;
- // slave VM opens file and acquires exclusive lock
- slave.open(file.getPath()).lock();
+ // worker VM opens file and acquires exclusive lock
+ worker.open(file.getPath()).lock();
AsynchronousFileChannel ch = AsynchronousFileChannel
.open(file.toPath(), READ, WRITE);
// this VM tries to acquire lock
// (lock should not be acquire until released by slave VM)
Future
@@ -59,31 +59,31 @@ public class Lock {
.open(file.toPath(), READ, WRITE);
// this VM tries to acquire lock
- // (lock should not be acquire until released by slave VM)
+ // (lock should not be acquire until released by worker VM)
Future